@@ -78,224 +78,192 @@ class AuthorizationErrorException(ServiceException):
     code: str = "AuthorizationError"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class BatchEntryIdsNotDistinctException(ServiceException):
     code: str = "BatchEntryIdsNotDistinct"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class BatchRequestTooLongException(ServiceException):
     code: str = "BatchRequestTooLong"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class ConcurrentAccessException(ServiceException):
     code: str = "ConcurrentAccess"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class EmptyBatchRequestException(ServiceException):
     code: str = "EmptyBatchRequest"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class EndpointDisabledException(ServiceException):
     code: str = "EndpointDisabled"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class FilterPolicyLimitExceededException(ServiceException):
     code: str = "FilterPolicyLimitExceeded"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class InternalErrorException(ServiceException):
     code: str = "InternalError"
     sender_fault: bool = False
     status_code: int = 500
-    message: Optional[string]
 
 
 class InvalidBatchEntryIdException(ServiceException):
     code: str = "InvalidBatchEntryId"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class InvalidParameterException(ServiceException):
     code: str = "InvalidParameter"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class InvalidParameterValueException(ServiceException):
     code: str = "ParameterValueInvalid"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class InvalidSecurityException(ServiceException):
     code: str = "InvalidSecurity"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class KMSAccessDeniedException(ServiceException):
     code: str = "KMSAccessDenied"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class KMSDisabledException(ServiceException):
     code: str = "KMSDisabled"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class KMSInvalidStateException(ServiceException):
     code: str = "KMSInvalidState"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class KMSNotFoundException(ServiceException):
     code: str = "KMSNotFound"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class KMSOptInRequired(ServiceException):
     code: str = "KMSOptInRequired"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class KMSThrottlingException(ServiceException):
     code: str = "KMSThrottling"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class NotFoundException(ServiceException):
     code: str = "NotFound"
     sender_fault: bool = True
     status_code: int = 404
-    message: Optional[string]
 
 
 class OptedOutException(ServiceException):
     code: str = "OptedOut"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class PlatformApplicationDisabledException(ServiceException):
     code: str = "PlatformApplicationDisabled"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class ResourceNotFoundException(ServiceException):
     code: str = "ResourceNotFound"
     sender_fault: bool = True
     status_code: int = 404
-    message: Optional[string]
 
 
 class StaleTagException(ServiceException):
     code: str = "StaleTag"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class SubscriptionLimitExceededException(ServiceException):
     code: str = "SubscriptionLimitExceeded"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class TagLimitExceededException(ServiceException):
     code: str = "TagLimitExceeded"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class TagPolicyException(ServiceException):
     code: str = "TagPolicy"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class ThrottledException(ServiceException):
     code: str = "Throttled"
     sender_fault: bool = True
     status_code: int = 429
-    message: Optional[string]
 
 
 class TooManyEntriesInBatchRequestException(ServiceException):
     code: str = "TooManyEntriesInBatchRequest"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class TopicLimitExceededException(ServiceException):
     code: str = "TopicLimitExceeded"
     sender_fault: bool = True
     status_code: int = 403
-    message: Optional[string]
 
 
 class UserErrorException(ServiceException):
     code: str = "UserError"
     sender_fault: bool = True
     status_code: int = 400
-    message: Optional[string]
 
 
 class ValidationException(ServiceException):
     code: str = "ValidationException"
     sender_fault: bool = True
     status_code: int = 400
-    Message: string
 
 
 class VerificationException(ServiceException):
     code: str = "VerificationException"
     sender_fault: bool = False
     status_code: int = 400
-    Message: string
     Status: string
 
 
