@@ -25,6 +25,7 @@ from localstack.services.awslambda import lambda_executors
 from localstack.services.awslambda.event_source_listeners.event_source_listener import (
     EventSourceListener,
 )
+from localstack.services.awslambda.invocation.lambda_util import function_name_from_arn
 from localstack.services.awslambda.lambda_executors import InvocationResult, LambdaContext
 from localstack.services.awslambda.lambda_utils import (
     API_PATH_ROOT,
@@ -515,6 +516,13 @@ def run_lambda(
 ) -> InvocationResult:
     if context is None:
         context = {}
+
+    # Ensure that the service provider has been initialized. This is required to ensure all lifecycle hooks
+    # (e.g., persistence) have been executed when the run_lambda(..) function gets called (e.g., from API GW).
+    if not hasattr(run_lambda, "_provider_initialized"):
+        aws_stack.connect_to_service("lambda").list_functions()
+        run_lambda._provider_initialized = True
+
     region_name = func_arn.split(":")[3]
     region = LambdaRegion.get(region_name)
     if suppress_output:
@@ -1014,6 +1022,8 @@ def get_lambda_policy(function, qualifier=None):
 
 def get_lambda_policy_name(resource_name: str, qualifier: str = None) -> str:
     qualifier = qualifier or "latest"
+    if ":function:" in resource_name:
+        resource_name = function_name_from_arn(resource_name)
     return LAMBDA_POLICY_NAME_PATTERN.format(name=resource_name, qualifier=qualifier)
 
 
