@@ -1,5 +1,4 @@
 from datetime import datetime, timezone
-from typing import Optional
 
 from moto.route53resolver.models import Route53ResolverBackend as MotoRoute53ResolverBackend
 from moto.route53resolver.models import route53resolver_backends as moto_route53resolver_backends
@@ -7,6 +6,7 @@ from moto.route53resolver.models import route53resolver_backends as moto_route53
 from localstack.aws.api import RequestContext
 from localstack.aws.api.route53resolver import (
     Action,
+    AssociateFirewallRuleGroupResponse,
     BlockOverrideDnsType,
     BlockOverrideDomain,
     BlockOverrideTtl,
@@ -18,6 +18,7 @@ from localstack.aws.api.route53resolver import (
     DeleteFirewallDomainListResponse,
     DeleteFirewallRuleGroupResponse,
     DeleteFirewallRuleResponse,
+    DisassociateFirewallRuleGroupResponse,
     FirewallDomainList,
     FirewallDomainListMetadata,
     FirewallDomainName,
@@ -25,8 +26,10 @@ from localstack.aws.api.route53resolver import (
     FirewallDomainUpdateOperation,
     FirewallRule,
     FirewallRuleGroup,
+    FirewallRuleGroupAssociation,
     FirewallRuleGroupMetadata,
     GetFirewallDomainListResponse,
+    GetFirewallRuleGroupAssociationResponse,
     GetFirewallRuleGroupResponse,
     ListDomainMaxResults,
     ListFirewallDomainListsResponse,
@@ -34,6 +37,7 @@ from localstack.aws.api.route53resolver import (
     ListFirewallRuleGroupsResponse,
     ListFirewallRulesResponse,
     MaxResults,
+    MutationProtectionStatus,
     Name,
     NextToken,
     Priority,
@@ -42,22 +46,32 @@ from localstack.aws.api.route53resolver import (
     Route53ResolverApi,
     TagList,
     UpdateFirewallDomainsResponse,
+    UpdateFirewallRuleGroupAssociationResponse,
     UpdateFirewallRuleResponse,
     ValidationException,
 )
-from localstack.services.route53resolver.models import Route53ResolverBackend
+from localstack.services.route53resolver.models import (
+    Route53ResolverBackend,
+    delete_firewall_domain_list,
+    delete_firewall_rule,
+    delete_firewall_rule_group,
+    delete_firewall_rule_group_association,
+    get_firewall_domain,
+    get_firewall_domain_list,
+    get_firewall_rule,
+    get_firewall_rule_group,
+    get_firewall_rule_group_association,
+)
+from localstack.services.route53resolver.utils import (
+    get_route53_resolver_firewall_domain_list_id,
+    get_route53_resolver_firewall_rule_group_association_id,
+    get_route53_resolver_firewall_rule_group_id,
+    validate_mutation_protection,
+    validate_priority,
+)
 from localstack.utils.aws import aws_stack
 from localstack.utils.collections import select_from_typed_dict
 from localstack.utils.patch import patch
-from localstack.utils.strings import get_random_hex
-
-
-def get_route53_resolver_firewall_rule_group_id():
-    return f"rslvr-frg-{get_random_hex(17)}"
-
-
-def get_route53_resolver_firewall_domain_list_id():
-    return f"rslvr-fdl-{get_random_hex(17)}"
 
 
 class Route53ResolverProvider(Route53ResolverApi):
@@ -68,10 +82,11 @@ class Route53ResolverProvider(Route53ResolverApi):
         name: Name,
         tags: TagList = None,
     ) -> CreateFirewallRuleGroupResponse:
+        """Create a Firewall Rule Group."""
         region_details = Route53ResolverBackend.get()
         id = get_route53_resolver_firewall_rule_group_id()
         arn = aws_stack.get_route53_resolver_firewall_rule_group_arn(id)
-        firewall_rule_group: Optional[FirewallRuleGroup] = FirewallRuleGroup(
+        firewall_rule_group = FirewallRuleGroup(
             Id=id,
             Arn=arn,
             Name=name,
@@ -91,32 +106,21 @@ class Route53ResolverProvider(Route53ResolverApi):
     def delete_firewall_rule_group(
         self, context: RequestContext, firewall_rule_group_id: ResourceId
     ) -> DeleteFirewallRuleGroupResponse:
-        region_details = Route53ResolverBackend.get()
-        if not region_details.firewall_rule_groups.get(firewall_rule_group_id):
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_rule_group_id}'. Trace Id: '1-{get_random_hex(8)}-{get_random_hex(24)}'"
-            )
-        firewall_rule_group: Optional[FirewallRuleGroup] = region_details.firewall_rule_groups.pop(
-            firewall_rule_group_id
-        )
+        """Delete a Firewall Rule Group."""
+        firewall_rule_group: FirewallRuleGroup = delete_firewall_rule_group(firewall_rule_group_id)
         return DeleteFirewallRuleGroupResponse(FirewallRuleGroup=firewall_rule_group)
 
     def get_firewall_rule_group(
         self, context: RequestContext, firewall_rule_group_id: ResourceId
     ) -> GetFirewallRuleGroupResponse:
-        region_details = Route53ResolverBackend.get()
-        firewall_rule_group: Optional[FirewallRuleGroup] = region_details.firewall_rule_groups.get(
-            firewall_rule_group_id
-        )
-        if not firewall_rule_group:
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_rule_group_id}'. Trace Id: '1-{get_random_hex(8)}-{get_random_hex(24)}'"
-            )
+        """Get the details of a Firewall Rule Group."""
+        firewall_rule_group: FirewallRuleGroup = get_firewall_rule_group(firewall_rule_group_id)
         return GetFirewallRuleGroupResponse(FirewallRuleGroup=firewall_rule_group)
 
     def list_firewall_rule_groups(
         self, context: RequestContext, max_results: MaxResults = None, next_token: NextToken = None
     ) -> ListFirewallRuleGroupsResponse:
+        """List Firewall Rule Groups."""
         region_details = Route53ResolverBackend.get()
         firewall_rule_groups = []
         for firewall_rule_group in region_details.firewall_rule_groups.values():
@@ -132,6 +136,7 @@ class Route53ResolverProvider(Route53ResolverApi):
         name: Name,
         tags: TagList = None,
     ) -> CreateFirewallDomainListResponse:
+        """Create a Firewall Domain List."""
         region_details = Route53ResolverBackend.get()
         id = get_route53_resolver_firewall_domain_list_id()
         arn = aws_stack.get_route53_resolver_firewall_domain_list_arn(id)
@@ -154,32 +159,23 @@ class Route53ResolverProvider(Route53ResolverApi):
     def delete_firewall_domain_list(
         self, context: RequestContext, firewall_domain_list_id: ResourceId
     ) -> DeleteFirewallDomainListResponse:
-        region_details = Route53ResolverBackend.get()
-        if not region_details.firewall_domain_lists.get(firewall_domain_list_id):
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_domain_list_id}'. Trace Id: '{aws_stack.get_trace_id()}'"
-            )
-        firewall_domain_list: Optional[
-            FirewallDomainList
-        ] = region_details.firewall_domain_lists.pop(firewall_domain_list_id)
+        """Delete a Firewall Domain List."""
+        firewall_domain_list: FirewallDomainList = delete_firewall_domain_list(
+            firewall_domain_list_id
+        )
         return DeleteFirewallDomainListResponse(FirewallDomainList=firewall_domain_list)
 
     def get_firewall_domain_list(
         self, context: RequestContext, firewall_domain_list_id: ResourceId
     ) -> GetFirewallDomainListResponse:
-        region_details = Route53ResolverBackend.get()
-        firewall_domain_list: Optional[
-            FirewallDomainList
-        ] = region_details.firewall_domain_lists.get(firewall_domain_list_id)
-        if not firewall_domain_list:
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_domain_list_id}'. Trace Id: '{aws_stack.get_trace_id()}'"
-            )
+        """Get the details of a Firewall Domain List."""
+        firewall_domain_list: FirewallDomainList = get_firewall_domain_list(firewall_domain_list_id)
         return GetFirewallDomainListResponse(FirewallDomainList=firewall_domain_list)
 
     def list_firewall_domain_lists(
         self, context: RequestContext, max_results: MaxResults = None, next_token: NextToken = None
     ) -> ListFirewallDomainListsResponse:
+        """List all Firewall Domain Lists."""
         region_details = Route53ResolverBackend.get()
         firewall_domain_lists = []
         for firewall_domain_list in region_details.firewall_domain_lists.values():
@@ -195,20 +191,19 @@ class Route53ResolverProvider(Route53ResolverApi):
         operation: FirewallDomainUpdateOperation,
         domains: FirewallDomains,
     ) -> UpdateFirewallDomainsResponse:
+        """Update the domains in a Firewall Domain List."""
         region_details = Route53ResolverBackend.get()
-        firewall_domain_list: FirewallDomainList = region_details.firewall_domain_lists.get(
-            firewall_domain_list_id
-        )
-        if not firewall_domain_list:
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_domain_list_id}'. Trace Id: '{aws_stack.get_trace_id()}'"
-            )
-        firewall_domains = region_details.firewall_domains.get(firewall_domain_list_id)
+        firewall_domain_list: FirewallDomainList = get_firewall_domain_list(firewall_domain_list_id)
+
+        firewall_domain_list: FirewallDomainList = get_firewall_domain_list(firewall_domain_list_id)
+        firewall_domains = get_firewall_domain(firewall_domain_list_id)
+
         if operation == FirewallDomainUpdateOperation.ADD:
             if not firewall_domains:
                 region_details.firewall_domains[firewall_domain_list_id] = domains
             else:
                 region_details.firewall_domains[firewall_domain_list_id].append(domains)
+
         if operation == FirewallDomainUpdateOperation.REMOVE:
             if firewall_domains:
                 for domain in domains:
@@ -218,9 +213,12 @@ class Route53ResolverProvider(Route53ResolverApi):
                         raise ValidationException(
                             f"[RSLVR-02502] The following domains don't exist in the DNS Firewall domain list '{firewall_domain_list_id}'. You can't delete a domain that isn't in a domain list. Example unknown domain: '{domain}'. Trace Id: '{aws_stack.get_trace_id()}'"
                         )
+
         if operation == FirewallDomainUpdateOperation.REPLACE:
             region_details.firewall_domains[firewall_domain_list_id] = domains
+
         firewall_domain_list["StatusMessage"] = "Finished domain list update"
+        firewall_domain_list["ModificationTime"] = datetime.now(timezone.utc).isoformat()
         return UpdateFirewallDomainsResponse(
             Id=firewall_domain_list.get("Id"),
             Name=firewall_domain_list.get("Name"),
@@ -235,6 +233,7 @@ class Route53ResolverProvider(Route53ResolverApi):
         max_results: ListDomainMaxResults = None,
         next_token: NextToken = None,
     ) -> ListFirewallDomainsResponse:
+        """List the domains in a DNS Firewall domain list."""
         region_details = Route53ResolverBackend.get()
         firewall_domains: FirewallDomains[FirewallDomainName] = []
         if region_details.firewall_domains.get(firewall_domain_list_id):
@@ -256,6 +255,7 @@ class Route53ResolverProvider(Route53ResolverApi):
         block_override_dns_type: BlockOverrideDnsType = None,
         block_override_ttl: BlockOverrideTtl = None,
     ) -> CreateFirewallRuleResponse:
+        """Create a new firewall rule"""
         region_details = Route53ResolverBackend.get()
         firewall_rule = FirewallRule(
             FirewallRuleGroupId=firewall_rule_group_id,
@@ -288,16 +288,10 @@ class Route53ResolverProvider(Route53ResolverApi):
         firewall_rule_group_id: ResourceId,
         firewall_domain_list_id: ResourceId,
     ) -> DeleteFirewallRuleResponse:
-        region_details = Route53ResolverBackend.get()
-        if not region_details.firewall_rules.get(firewall_rule_group_id, {}).get(
-            firewall_domain_list_id
-        ):
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_rule_group_id}'. Trace Id: '{aws_stack.get_trace_id()}'"
-            )
-        firewall_rule: FirewallRule = region_details.firewall_rules.get(
-            firewall_rule_group_id, {}
-        ).pop(firewall_domain_list_id)
+        """Delete a firewall rule"""
+        firewall_rule: FirewallRule = delete_firewall_rule(
+            firewall_rule_group_id, firewall_domain_list_id
+        )
         return DeleteFirewallRuleResponse(
             FirewallRule=firewall_rule,
         )
@@ -311,6 +305,8 @@ class Route53ResolverProvider(Route53ResolverApi):
         max_results: MaxResults = None,
         next_token: NextToken = None,
     ) -> ListFirewallRulesResponse:
+        """List all the firewall rules in a firewall rule group."""
+        # TODO: implement priority and action filtering
         region_details = Route53ResolverBackend.get()
         firewall_rules = []
         for firewall_rule in region_details.firewall_rules.get(firewall_rule_group_id, {}).values():
@@ -336,14 +332,11 @@ class Route53ResolverProvider(Route53ResolverApi):
         block_override_ttl: BlockOverrideTtl = None,
         name: Name = None,
     ) -> UpdateFirewallRuleResponse:
-        region_details = Route53ResolverBackend.get()
-        firewall_rule: FirewallRule = region_details.firewall_rules.get(
-            firewall_rule_group_id, {}
-        ).get(firewall_domain_list_id)
-        if not firewall_rule:
-            raise ResourceNotFoundException(
-                f"Can't find the resource with ID '{firewall_rule_group_id}'. Trace Id: '{aws_stack.get_trace_id()}'"
-            )
+        """Updates a firewall rule"""
+        firewall_rule: FirewallRule = get_firewall_rule(
+            firewall_rule_group_id, firewall_domain_list_id
+        )
+
         if priority:
             firewall_rule["Priority"] = priority
         if action:
@@ -362,6 +355,106 @@ class Route53ResolverProvider(Route53ResolverApi):
             FirewallRule=firewall_rule,
         )
 
+    def associate_firewall_rule_group(
+        self,
+        context: RequestContext,
+        creator_request_id: CreatorRequestId,
+        firewall_rule_group_id: ResourceId,
+        vpc_id: ResourceId,
+        priority: Priority,
+        name: Name,
+        mutation_protection: MutationProtectionStatus = None,
+        tags: TagList = None,
+    ) -> AssociateFirewallRuleGroupResponse:
+        """Associate a firewall rule group with a VPC."""
+        region_details = Route53ResolverBackend.get()
+        validate_priority(priority=priority)
+        validate_mutation_protection(mutation_protection=mutation_protection)
+
+        for (
+            firewall_rule_group_association
+        ) in region_details.firewall_rule_group_associations.values():
+            if (
+                firewall_rule_group_association.get("VpcId") == vpc_id
+                and firewall_rule_group_association.get("FirewallRuleGroupId")
+                == firewall_rule_group_id
+            ):
+                raise ValidationException(
+                    f"[RSLVR-02302] This DNS Firewall rule group can't be associated to a VPC: '{vpc_id}'. It is already associated to VPC '{firewall_rule_group_id}'. Try again with another VPC or DNS Firewall rule group. Trace Id: '{aws_stack.get_trace_id()}'"
+                )
+
+        id = get_route53_resolver_firewall_rule_group_association_id()
+        arn = aws_stack.get_route53_resolver_firewall_rule_group_associations_arn(id)
+
+        firewall_rule_group_association = FirewallRuleGroupAssociation(
+            Id=id,
+            Arn=arn,
+            FirewallRuleGroupId=firewall_rule_group_id,
+            VpcId=vpc_id,
+            Name=name,
+            Priority=priority,
+            MutationProtection=mutation_protection or "DISABLED",
+            Status="COMPLETE",
+            StatusMessage="Creating Firewall Rule Group Association",
+            CreatorRequestId=creator_request_id,
+            CreationTime=datetime.now(timezone.utc).isoformat(),
+            ModificationTime=datetime.now(timezone.utc).isoformat(),
+        )
+        region_details.firewall_rule_group_associations[id] = firewall_rule_group_association
+        moto_route53resolver_backends[context.region].tagger.tag_resource(arn, tags or [])
+        return AssociateFirewallRuleGroupResponse(
+            FirewallRuleGroupAssociation=firewall_rule_group_association
+        )
+
+    def disassociate_firewall_rule_group(
+        self, context: RequestContext, firewall_rule_group_association_id: ResourceId
+    ) -> DisassociateFirewallRuleGroupResponse:
+        """Disassociate a DNS Firewall rule group from a VPC."""
+        firewall_rule_group_association: FirewallRuleGroupAssociation = (
+            delete_firewall_rule_group_association(firewall_rule_group_association_id)
+        )
+        return DisassociateFirewallRuleGroupResponse(
+            FirewallRuleGroupAssociation=firewall_rule_group_association
+        )
+
+    def get_firewall_rule_group_association(
+        self, context: RequestContext, firewall_rule_group_association_id: ResourceId
+    ) -> GetFirewallRuleGroupAssociationResponse:
+        """Returns the Firewall Rule Group Association that you specified."""
+        firewall_rule_group_association: FirewallRuleGroupAssociation = (
+            get_firewall_rule_group_association(firewall_rule_group_association_id)
+        )
+        return GetFirewallRuleGroupAssociationResponse(
+            FirewallRuleGroupAssociation=firewall_rule_group_association
+        )
+
+    def update_firewall_rule_group_association(
+        self,
+        context: RequestContext,
+        firewall_rule_group_association_id: ResourceId,
+        priority: Priority = None,
+        mutation_protection: MutationProtectionStatus = None,
+        name: Name = None,
+    ) -> UpdateFirewallRuleGroupAssociationResponse:
+        """Updates the specified Firewall Rule Group Association."""
+        validate_priority(priority=priority)
+        validate_mutation_protection(mutation_protection=mutation_protection)
+
+        firewall_rule_group_association: FirewallRuleGroupAssociation = (
+            get_firewall_rule_group_association(firewall_rule_group_association_id)
+        )
+
+        if priority:
+            firewall_rule_group_association["Priority"] = priority
+        if mutation_protection:
+            firewall_rule_group_association["MutationProtection"] = mutation_protection
+        if name:
+            firewall_rule_group_association["Name"] = name
+
+        return UpdateFirewallRuleGroupAssociationResponse(
+            FirewallRuleGroupAssociation=firewall_rule_group_association
+        )
+
 
 @patch(MotoRoute53ResolverBackend._matched_arn)
 def Route53ResolverBackend_matched_arn(fn, self, resource_arn):
@@ -373,4 +466,7 @@ def Route53ResolverBackend_matched_arn(fn, self, resource_arn):
     for firewall_domain_list in region_details.firewall_domain_lists.values():
         if firewall_domain_list.get("Arn") == resource_arn:
             return
+    for firewall_rule_group_association in region_details.firewall_rule_group_associations.values():
+        if firewall_rule_group_association.get("Arn") == resource_arn:
+            return
     fn(self, resource_arn)
